@@ -23,7 +23,7 @@ pub enum Complexity {
 
 /// Holds parameters which specify how multiple cores are used
 /// to execute an operation.
-#[derive(Debug, Copy)]
+#[derive(Debug, Copy, Clone)]
 #[repr(C)]
 pub struct MultiCoreSettings {
     /// All operations will be limited to not create more threads than specified here
@@ -51,19 +51,6 @@ impl MultiCoreSettings {
     }
 }
 
-impl Clone for MultiCoreSettings {
-    fn clone(&self) -> Self {
-        MultiCoreSettings {
-            core_limit: self.core_limit,
-            early_temp_allocation: self.early_temp_allocation,
-        }
-    }
-
-    fn clone_from(&mut self, source: &Self) {
-        self.core_limit = source.core_limit;
-    }
-}
-
 /// Contains logic which helps to perform an operation
 /// in parallel by dividing an array into chunks.
 pub struct Chunk;
@@ -97,13 +84,16 @@ impl Chunk {
         if cores > settings.core_limit {
             cores = settings.core_limit;
         }
+        
         if cores == 1 {
             cores
         } else if complexity == Complexity::Small {
             if array_length < 500000 {
                 1
-            } else {
-                if cores >= 2 { 2 } else { 1 }
+            } else if cores >= 2 { 
+                2 
+            } else { 
+                1 
             }
         } else if complexity == Complexity::Medium {
             if array_length < 10000 {
@@ -113,9 +103,11 @@ impl Chunk {
             } else {
                 cores
             }
-        } else {
+        } else if array_length < 30000 {
             // complexity == Complexity::Large
-            if array_length < 30000 { 1 } else { cores }
+            1
+        } else { 
+            cores 
         }
     }
 
