@@ -37,6 +37,7 @@ pub trait ReorganizeDataOps<T>
     fn swap_halves(&mut self);
 }
 
+#[deprecated(since="0.4.1", note="please use `ReorganizeDataOps` instead which offers the same performance without a buffer")]
 pub trait ReorganizeDataOpsBuffered<S, T>
     where T: RealNumber,
           S: ToSliceMut<T>
@@ -218,6 +219,17 @@ pub trait MergeOps {
     fn merge(&mut self, sources: &[&Self]) -> VoidResult;
 }
 
+fn reverse_array<T>(data: &mut [T])
+    where T: Copy {
+    let len = data.len();
+    // +1 makes sure that for odd numbers the first `lo` gets the extra item
+    // (which is later on ignored)
+    let (lo, up) = data.split_at_mut((len + 1) / 2);
+    for (lo, up) in lo.iter_mut().zip(up.iter_mut().rev()) {
+        mem::swap(lo, up);
+    }
+}
+
 impl<S, T, N, D> ReorganizeDataOps<T> for DspVec<S, T, N, D>
     where S: ToSliceMut<T> + Owner,
           T: RealNumber,
@@ -225,89 +237,33 @@ impl<S, T, N, D> ReorganizeDataOps<T> for DspVec<S, T, N, D>
           D: Domain
 {
     fn reverse(&mut self) {
+        let len = self.len();
         if self.is_complex() {
-            let len = self.points();
             let mut data = self.data.to_slice_mut();
-            let mut data = array_to_complex_mut(&mut data[..]);
-            for i in 0..len / 2 {
-                let temp = data[i];
-                data[i] = data[len - 1 - i];
-                data[len - 1 - i] = temp;
-            }
+            let mut data = array_to_complex_mut(&mut data[0..len]);
+            reverse_array(data);
         } else {
-            let len = self.len();
             let mut data = self.data.to_slice_mut();
-            for i in 0..len / 2 {
-                let temp = data[i];
-                data[i] = data[len - 1 - i];
-                data[len - 1 - i] = temp;
-            }
+            reverse_array(&mut data[0..len]);
         }
     }
 
     fn swap_halves(&mut self) {
-        if self.is_complex() {
-            let len = self.points();
-            if len == 0 {
-                return;
-            }
-            let mut data = self.data.to_slice_mut();
-            let mut data = array_to_complex_mut(&mut data[..]);
-            if len % 2 == 0 {
-                for i in 0..len / 2 {
-                    let temp = data[i];
-                    data[i] = data[len / 2 + i];
-                    data[len / 2 + i] = temp;
-                }
-            } else {
-                let mut temp = data[0];
-                let mut pos = len / 2;
-                for _ in 0..len {
-                    let pos_new = (pos + len / 2) % len;
-                    let temp_new = data[pos];
-                    data[pos] = temp;
-                    temp = temp_new;
-                    pos = pos_new;
-                }
-            }
-
-        } else {
-            let len = self.len();
-            if len == 0 {
-                return;
-            }
-            let mut data = self.data.to_slice_mut();
-            if len % 2 == 0 {
-                for i in 0..len / 2 {
-                    let temp = data[i];
-                    data[i] = data[len / 2 + i];
-                    data[len / 2 + i] = temp;
-                }
-            } else {
-                let mut temp = data[0];
-                let mut pos = len / 2;
-                for _ in 0..len {
-                    let pos_new = (pos + len / 2) % len;
-                    let temp_new = data[pos];
-                    data[pos] = temp;
-                    temp = temp_new;
-                    pos = pos_new;
-                }
-            }
-        }
+        self.swap_halves_priv(true);
     }
 }
 
+#[allow(deprecated)]
 impl<S, T, N, D> ReorganizeDataOpsBuffered<S, T> for DspVec<S, T, N, D>
     where S: ToSliceMut<T> + Owner,
           T: RealNumber,
           N: NumberSpace,
           D: Domain
 {
-    fn swap_halves_b<B>(&mut self, buffer: &mut B)
+    fn swap_halves_b<B>(&mut self, _: &mut B)
         where B: Buffer<S, T>
     {
-        self.swap_halves_priv(buffer, true);
+        self.swap_halves_priv(true);
     }
 }
 
@@ -564,8 +520,8 @@ impl<S, T, N, D> SplitOps for DspVec<S, T, N, D>
             return Err(ErrorReason::InvalidArgumentLength);
         }
 
-        for i in 0..num_targets {
-            try!(targets[i].resize(data_length / num_targets));
+        for t in targets.iter_mut() {
+            try!(t.resize(data_length / num_targets));
         }
 
         let data = &self.data.to_slice();
@@ -577,10 +533,10 @@ impl<S, T, N, D> SplitOps for DspVec<S, T, N, D>
                 target[2 * pos + 1] = data[2 * i + 1];
             }
         } else {
-            for i in 0..data_length {
+            for (i, d) in data.iter().enumerate() {
                 let target = targets[i % num_targets].data.to_slice_mut();
                 let pos = i / num_targets;
-                target[pos] = data[i];
+                target[pos] = *d;
             }
         }
 
@@ -601,8 +557,8 @@ impl<S, T, N, D> MergeOps for DspVec<S, T, N, D>
                 return Err(ErrorReason::InvalidArgumentLength);
             }
 
-            for i in 1..num_sources {
-                if sources[0].len() != sources[i].len() {
+            for src in sources.iter().take(num_sources).skip(1) {
+                if sources[0].len() != src.len() {
                     return Err(ErrorReason::InvalidArgumentLength);
                 }
             }
@@ -620,10 +576,10 @@ impl<S, T, N, D> MergeOps for DspVec<S, T, N, D>
                     data[2 * i + 1] = source[2 * pos + 1];
                 }
             } else {
-                for i in 0..data_length {
+                for (i, d) in data.iter_mut().enumerate() {
                     let source = sources[i % num_sources].data.to_slice();
                     let pos = i / num_sources;
-                    data[i] = source[pos];
+                    *d = source[pos];
                 }
             }
         }
@@ -684,40 +640,6 @@ mod tests {
         assert_eq!(&v[..], &expected);
     }
 
-    #[test]
-    fn swap_halves_b_real_even_test() {
-        let mut v = vec![1.0, 2.0, 3.0, 4.0].to_real_time_vec();
-        let mut buffer = SingleBuffer::new();
-        v.swap_halves_b(&mut buffer);
-        assert_eq!(&v[..], &[3.0, 4.0, 1.0, 2.0]);
-    }
-
-    #[test]
-    fn swap_halves_b_real_odd_test() {
-        let mut v = vec![1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0]
-            .to_real_time_vec();
-        let mut buffer = SingleBuffer::new();
-        v.swap_halves_b(&mut buffer);
-        assert_eq!(&v[..],
-                   &[7.0, 8.0, 9.0, 10.0, 11.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0]);
-    }
-
-    #[test]
-    fn swap_halves_b_complex_even_test() {
-        let mut v = vec![1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0].to_complex_time_vec();
-        let mut buffer = SingleBuffer::new();
-        v.swap_halves_b(&mut buffer);
-        assert_eq!(&v[..], &[5.0, 6.0, 7.0, 8.0, 1.0, 2.0, 3.0, 4.0]);
-    }
-
-    #[test]
-    fn swap_halves_b_complex_odd_test() {
-        let mut v = vec![1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0].to_complex_time_vec();
-        let mut buffer = SingleBuffer::new();
-        v.swap_halves_b(&mut buffer);
-        assert_eq!(&v[..], &[7.0, 8.0, 9.0, 10.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0]);
-    }
-
     #[test]
     fn zero_pad_b_end_test() {
         let mut v = vec![1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0].to_complex_time_vec();
