@@ -49,6 +49,7 @@ pub trait StatisticsOps<T>: Sized
     /// ```
     fn statistics(&self) -> T;
 
+
     /// Calculates the statistics of the data contained in the vector as if the vector would
     /// have been split into `len` pieces. `self.len` should be dividable by
     /// `len` without a remainder,
@@ -63,11 +64,14 @@ pub trait StatisticsOps<T>: Sized
     /// use basic_dsp_vector::*;
     /// # fn main() {
     /// let vector = vec!(1.0, 2.0, 3.0, 4.0, 5.0, 6.0).to_complex_time_vec();
-    /// let result = vector.statistics_splitted(2);
+    /// let result = vector.statistics_split(2);
     /// assert_eq!(result[0].sum, Complex32::new(6.0, 8.0));
     /// assert_eq!(result[1].sum, Complex32::new(3.0, 4.0));
     /// }
     /// ```
+    fn statistics_split(&self, len: usize) -> Vec<T>;
+
+    #[deprecated(since="0.4.1", note="Use `statistics_split` which is the same method but comes with correct spelling")]
     fn statistics_splitted(&self, len: usize) -> Vec<T>;
 }
 
@@ -119,7 +123,7 @@ pub trait Stats<T>: Sized {
 macro_rules! impl_common_stats {
     () => {
         fn merge_cols(stats: &[Vec<Self>]) -> Vec<Self> {
-            if stats.len() == 0 {
+            if stats.is_empty() {
                 return Vec::new();
             }
 
@@ -127,9 +131,9 @@ macro_rules! impl_common_stats {
             let mut results = Vec::with_capacity(len);
             for i in 0..len {
                 let mut reordered = Vec::with_capacity(stats.len());
-                for j in 0..stats.len()
+                for s in stats.iter()
                 {
-                    reordered.push(stats[j][i]);
+                    reordered.push(s[i]);
                 }
 
                 let merged = Statistics::merge(&reordered);
@@ -278,7 +282,7 @@ impl<T> Stats<Complex<T>> for Statistics<Complex<T>>
         let mut sum_squared = Complex::<T>::new(T::zero(), T::zero());
         for stat in stats {
             sum = sum + stat.sum;
-            count = count + stat.count;
+            count += stat.count;
             sum_squared = sum_squared + stat.rms; // We stored sum_squared in the field rms
             if stat.max.norm() > max_norm {
                 max = stat.max;
@@ -348,7 +352,7 @@ impl<S, T, N, D> StatisticsOps<Statistics<T>> for DspVec<S, T, N, D>
         Statistics::merge(&chunks)
     }
 
-    fn statistics_splitted(&self, len: usize) -> Vec<Statistics<T>> {
+    fn statistics_split(&self, len: usize) -> Vec<Statistics<T>> {
         if len == 0 {
             return Vec::new();
         }
@@ -374,6 +378,10 @@ impl<S, T, N, D> StatisticsOps<Statistics<T>> for DspVec<S, T, N, D>
 
         Statistics::merge_cols(&chunks)
     }
+
+    fn statistics_splitted(&self, len: usize) -> Vec<Statistics<T>> {
+        self.statistics_split(len)
+    }
 }
 
 impl<S, T, N, D> SumOps<T> for DspVec<S, T, N, D>
@@ -479,7 +487,7 @@ impl<S, T, N, D> StatisticsOps<Statistics<Complex<T>>> for DspVec<S, T, N, D>
         Statistics::merge(&chunks)
     }
 
-    fn statistics_splitted(&self, len: usize) -> Vec<Statistics<Complex<T>>> {
+    fn statistics_split(&self, len: usize) -> Vec<Statistics<Complex<T>>> {
         if len == 0 {
             return Vec::new();
         }
@@ -506,6 +514,10 @@ impl<S, T, N, D> StatisticsOps<Statistics<Complex<T>>> for DspVec<S, T, N, D>
 
         Statistics::merge_cols(&chunks)
     }
+
+    fn statistics_splitted(&self, len: usize) -> Vec<Statistics<Complex<T>>> {
+        self.statistics_split(len)
+    }
 }
 
 impl<S, T, N, D> SumOps<Complex<T>> for DspVec<S, T, N, D>
