@@ -101,7 +101,7 @@ fn interpolate_priv_scalar<T, TT>(temp: &mut [TT],
     for num in temp {
         let center = T::from(i).unwrap() / interpolation_factor;
         let rounded = center.floor();
-        let iter = WrappingIterator::new(&data,
+        let iter = WrappingIterator::new(data,
                                          rounded.to_isize().unwrap() - conv_len as isize - 1,
                                          2 * conv_len + 1);
         let mut sum = TT::zero();
@@ -190,7 +190,7 @@ impl<S, T, N, D> DspVec<S, T, N, D>
                                               delay);
             let mut shifts = Vec::with_capacity(vectors.len() * number_of_shifts);
             for vector in &vectors {
-                let shifted_copies = DspVec::create_shifted_copies(&vector);
+                let shifted_copies = DspVec::create_shifted_copies(vector);
                 for shift in shifted_copies {
                     shifts.push(shift);
                 }
@@ -268,12 +268,12 @@ impl<S, T, N, D> DspVec<S, T, N, D>
                                       interpolation_factor: usize,
                                       conv_len: usize,
                                       data: &[TT],
-                                      vectors: &Vec<GenDspVec<Vec<T>, T>>)
+                                      vectors: &[GenDspVec<Vec<T>, T>])
                                       -> TT
         where TT: Zero + Clone + From<T> + Copy + Add<Output = TT> + Mul<Output = TT>
     {
         let rounded = i / interpolation_factor;
-        let iter = WrappingIterator::new(&data,
+        let iter = WrappingIterator::new(data,
                                          rounded as isize - conv_len as isize,
                                          2 * conv_len + 1);
         let vector = &vectors[i % interpolation_factor];
@@ -402,7 +402,7 @@ impl<S, T, N, D> InterpolationOps<S, T> for DspVec<S, T, N, D>
         // Vector is always complex from here on
 
         fft(self, buffer, false); // fft
-        self.swap_halves_priv(buffer, true); // fft shift
+        self.swap_halves_priv(true); // fft shift
         let points = self.len() / 2;
         let interpolation_factorf = T::from(interpolation_factor).unwrap();
         self.multiply_function_priv(function.is_symmetric(),
@@ -410,7 +410,7 @@ impl<S, T, N, D> InterpolationOps<S, T> for DspVec<S, T, N, D>
                                     |array| array_to_complex_mut(array),
                                     function,
                                     |f, x| Complex::<T>::new(f.calc(x), T::zero()));
-        self.swap_halves_priv(buffer, false); // ifft shift
+        self.swap_halves_priv(false); // ifft shift
         fft(self, buffer, true); // ifft
         self.scale(T::one() / T::from(points).unwrap());
         if !is_complex {
